unit CheckOutFrm;

{
  InnoCVS
  Copyright (C) 2002 Jordan Russell. All rights reserved.
  http://www.jrsoftware.org/

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

  $Id: CheckOutFrm.pas,v 1.6 2002/01/09 06:23:40 jr Exp $

  Additional credits for this unit:
    Simon Steele
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TCheckOutForm = class(TForm)
    OKButton: TButton;
    CancelButton: TButton;
    GroupBox1: TGroupBox;
    Label1: TLabel;
    ServerTypeCombo: TComboBox;
    AddressLabel: TLabel;
    AddressEdit: TEdit;
    PathEdit: TEdit;
    Label4: TLabel;
    GroupBox2: TGroupBox;
    Label5: TLabel;
    ModuleEdit: TEdit;
    UserInfoGroup: TGroupBox;
    UserNameLabel: TLabel;
    UserNameEdit: TEdit;
    Label2: TLabel;
    RepositoryCombo: TComboBox;
    procedure ServerTypeComboClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure RepositoryComboClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

implementation

uses Main;

{$R *.DFM}

type
  TControlAccess = class(TControl);

procedure TCheckOutForm.ServerTypeComboClick(Sender: TObject);
begin
  if ServerTypeCombo.ItemIndex <> 1 then begin
    AddressLabel.Visible := True;
    AddressEdit.Visible := True;
    UserInfoGroup.Visible := True;
    PathEdit.Text := '/data/cvs';
  end
  else begin
    AddressLabel.Visible := False;
    AddressEdit.Visible := False;
    UserInfoGroup.Visible := False;
    PathEdit.Text := 'c:\cvs';
  end;
end;

procedure TCheckOutForm.FormShow(Sender: TObject);
var
  I: Integer;
  SL: TStringList;
begin
  SL := TStringList.Create;
  try
    for I := 0 to MainForm.Repositories.Count-1 do
      SL.Add(PRepository(MainForm.Repositories[I]).Name);
    SL.Sort;
    RepositoryCombo.Items.Assign(SL);
  finally
    SL.Free;
  end;
  RepositoryCombo.Items.Insert(0, '(none)');
  RepositoryCombo.ItemIndex := 0;
end;

procedure TCheckOutForm.RepositoryComboClick(Sender: TObject);

  procedure SetCtlEnabled(Ctl: TControl; AEnabled: Boolean);
  begin
    Ctl.Enabled := AEnabled;
    if AEnabled then
      TControlAccess(Ctl).Color := clWindow
    else
      TControlAccess(Ctl).ParentColor := True;
  end;

  procedure SetEditReadOnly(Ctl: TEdit; AReadOnly: Boolean);
  begin
    Ctl.ReadOnly := AReadOnly;
    if not AReadOnly then
      Ctl.Color := clWindow
    else
      Ctl.ParentColor := True;
  end;

var
  RepSelected: Boolean;
  Rep: PRepository;
begin
  RepSelected := (RepositoryCombo.ItemIndex > 0);
  SetCtlEnabled(ServerTypeCombo, not RepSelected);
  SetEditReadOnly(AddressEdit, RepSelected);
  SetEditReadOnly(PathEdit, RepSelected);
  SetEditReadOnly(UserNameEdit, RepSelected);
  if RepSelected then begin
    Rep := MainForm.Repositories[RepositoryCombo.ItemIndex-1];
    ServerTypeCombo.ItemIndex := Rep.ServerType;
    ServerTypeComboClick(Sender);
    AddressEdit.Text := Rep.Host;
    PathEdit.Text := Rep.Path;
    UserNameEdit.Text := Rep.UserName;
  end;
end;

end.
