unit FavoritesFrm;

{
  InnoCVS
  Copyright (C) 2002 Jordan Russell. All rights reserved.
  http://www.jrsoftware.org/

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

  $Id: FavoritesFrm.pas,v 1.1 2002/01/11 23:11:18 jr Exp $
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TFavoritesForm = class(TForm)
    CloseButton: TButton;
    GroupBox1: TGroupBox;
    FavoritesList: TListBox;
    DeleteButton: TButton;
    procedure FavoritesListClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure DeleteButtonClick(Sender: TObject);
  private
    { Private declarations }
    procedure RefreshFavoritesList;
  public
    { Public declarations }
  end;

implementation

uses
  Registry, Common;

{$R *.DFM}

procedure TFavoritesForm.FormCreate(Sender: TObject);
begin
  RefreshFavoritesList;
end;

procedure TFavoritesForm.RefreshFavoritesList;
var
  SL: TStringList;
  Reg: TRegistry;
  I: Integer;
begin
  FavoritesList.Clear;
  DeleteButton.Enabled := False;
  SL := nil;
  Reg := TRegistry.Create;
  try
    if not Reg.OpenKeyReadOnly(SRegistryFavoritesPath) then
      Exit;
    SL := TStringList.Create;
    Reg.GetKeyNames(SL);
    SL.Sort;
    for I := 0 to SL.Count-1 do
      FavoritesList.Items.Add(SL[I]);
  finally
    SL.Free;
    Reg.Free;
  end;
end;

procedure TFavoritesForm.FavoritesListClick(Sender: TObject);
begin
  DeleteButton.Enabled := (FavoritesList.ItemIndex >= 0);
end;

procedure TFavoritesForm.DeleteButtonClick(Sender: TObject);
var
  S: String;
  Reg: TRegistry;
begin
  if FavoritesList.ItemIndex < 0 then Exit;
  S := FavoritesList.Items[FavoritesList.ItemIndex];
  if Application.MessageBox(PChar('Are you sure you want to delete "' + S + '"?'),
     'Delete', MB_YESNO or MB_DEFBUTTON2 or MB_ICONEXCLAMATION) <> ID_YES then
    Exit;
  Reg := TRegistry.Create;
  try
    Reg.DeleteKey(SRegistryFavoritesPath + '\' + S);
  finally
    Reg.Free;
  end;
  RefreshFavoritesList;
end;

end.
