unit OptionsFrm;

{
  InnoCVS
  Copyright (C) 2002 Jordan Russell. All rights reserved.
  http://www.jrsoftware.org/

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

  $Id: OptionsFrm.pas,v 1.6 2002/01/12 02:18:47 jr Exp $

  Additional credits for this unit:
    Simon Steele
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls, Main;

type
  TOptionsForm = class(TForm)
    OKButton: TButton;
    CancelButton: TButton;
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    GroupBox1: TGroupBox;
    Label1: TLabel;
    HomeEdit: TEdit;
    GroupBox2: TGroupBox;
    Label4: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    CVSEdit: TEdit;
    TextViewerEdit: TEdit;
    ExternalDiffEdit: TEdit;
    TabSheet2: TTabSheet;
    Image1: TImage;
    Label5: TLabel;
    RepositoriesList: TListView;
    RepAddButton: TButton;
    RepEditButton: TButton;
    RepDeleteButton: TButton;
    GroupBox3: TGroupBox;
    OpenInNotepadCheck: TCheckBox;
    procedure RepositoriesListSelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
    procedure RepAddButtonClick(Sender: TObject);
    procedure RepDeleteButtonClick(Sender: TObject);
    procedure RepEditButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure RepositoriesListDblClick(Sender: TObject);
  private
    { Private declarations }
    procedure BuildRepositoriesList;
    procedure FreeRepositories;
    procedure UpdateRepositoriesListItem(ListItem: TListItem; Rep: PRepository);
  public
    { Public declarations }
    Repositories: TList;
    procedure CopyRepositories(Source: TList);
  end;

implementation

{$R *.DFM}

uses
  RepositoryFrm;

procedure TOptionsForm.FormCreate(Sender: TObject);
begin
  Repositories := TList.Create;
end;

procedure TOptionsForm.FormShow(Sender: TObject);
begin
  BuildRepositoriesList;
end;

procedure TOptionsForm.FormDestroy(Sender: TObject);
begin
  FreeRepositories;
end;

procedure TOptionsForm.UpdateRepositoriesListItem(ListItem: TListItem;
  Rep: PRepository);
begin
  ListItem.Caption := Rep.Name;
  ListItem.SubItems.Clear;
  if Rep.ServerType <> 1 then  { not local? }
    ListItem.SubItems.Add(Format('%s on %s', [Rep.Path, Rep.Host]))
  else
    ListItem.SubItems.Add(Rep.Path);
  ListItem.Data := Rep;
end;

procedure TOptionsForm.BuildRepositoriesList;
var
  I: Integer;
begin
  for I := 0 to Repositories.Count-1 do
    UpdateRepositoriesListItem(RepositoriesList.Items.Add, Repositories[I]);
end;

procedure TOptionsForm.CopyRepositories(Source: TList);
var
  SrcRep, DstRep: PRepository;
  I: Integer;
begin
  for I := 0 to Source.Count-1 do begin
    SrcRep := Source[I];
    New(DstRep);
    DstRep^ := SrcRep^;
    Repositories.Add(DstRep);
  end;
end;

procedure TOptionsForm.FreeRepositories;
var
  I: Integer;
begin
  if Assigned(Repositories) then begin
    for I := Repositories.Count-1 downto 0 do
      Dispose(PRepository(Repositories[I]));
    Repositories.Free;
  end;
end;

procedure TOptionsForm.RepositoriesListSelectItem(Sender: TObject;
  Item: TListItem; Selected: Boolean);
var
  SelItem: TListItem;
begin
  SelItem := RepositoriesList.Selected;
  RepEditButton.Enabled := Assigned(SelItem);
  RepDeleteButton.Enabled := Assigned(SelItem);
end;

procedure TOptionsForm.RepositoriesListDblClick(Sender: TObject);
begin
  RepEditButtonClick(Sender);
end;

procedure TOptionsForm.RepAddButtonClick(Sender: TObject);
var
  RepForm: TRepositoryForm;
  RName, Server, Path, UserName, Password: String;
  FoundItem: TListItem;
  Done: Boolean;
  Edit: Boolean;
  ServerType: Integer;
  Rep: PRepository;
begin
  RName := '';
  Server := '';
  Path := '';
  UserName := '';
  Password := '';
  ServerType := 0;

  RepForm := TRepositoryForm.Create(Self);
  try
    Done := False;
    Edit := False;
    while not Done do begin
      if RepForm.Execute(RName, Server, Path, UserName, ServerType, Edit) then begin
        FoundItem := RepositoriesList.FindCaption(0, RName, False, True, False);
        if not Assigned(FoundItem) then begin
          New(Rep);
          Rep.Name := RName;
          Rep.Host := Server;
          Rep.Path := Path;
          Rep.UserName := UserName;
          Rep.ServerType := ServerType;
          Repositories.Add(Rep);
          UpdateRepositoriesListItem(RepositoriesList.Items.Add, Rep);
          Done := True;
        end
        else begin
          ShowMessage('Repository friendly names must be unique!');
          Edit := True;
        end;
      end
      else
        Done := True;
    end;
  finally
    RepForm.Free;
  end;
end;

procedure TOptionsForm.RepDeleteButtonClick(Sender: TObject);
var
  ListItem: TListItem;
  Rep: PRepository;
begin
  ListItem := RepositoriesList.Selected;
  if Assigned(ListItem) then begin
    Rep := ListItem.Data;
    if Application.MessageBox(PChar('Are you sure you want to delete the repository "' +
       ListItem.Caption + '"?'), 'Delete', MB_YESNO or MB_DEFBUTTON2 or
       MB_ICONEXCLAMATION) = ID_YES then begin
      ListItem.Delete;
      Repositories.Remove(Rep);
      Dispose(Rep);
    end;
  end;
end;

procedure TOptionsForm.RepEditButtonClick(Sender: TObject);
var
  RepForm: TRepositoryForm;
  RName, Server, Path, UserName: String;
  ServerType: Integer;
  li, fi: TListItem;
  Done: Boolean;
  Rep: PRepository;
begin
  li := RepositoriesList.Selected;
  if li = nil then Exit;
  RName := li.Caption;
  Rep := PRepository(li.Data);
  Server := Rep.Host;
  Path := Rep.Path;
  UserName := Rep.UserName;
  ServerType := Rep.ServerType;

  RepForm := TRepositoryForm.Create(Self);
  try
    // This loop is to ensure no more than one repository with one name.
    Done := False;
    while not Done do begin
      if RepForm.Execute(RName, Server, Path, UserName, ServerType, True) then begin
        // Check that the name was not changed...
        if RName <> li.Caption then begin
          // If it was, we need to make sure that it didn't clash...
          fi := RepositoriesList.FindCaption(0, RName, False, True, False);
          if (not Assigned(fi)) or (fi = li) then
            Done := True
          else
            ShowMessage('Repository friendly names must be unique!');
        end
        else
          Done := True;

        if Done then begin
          Rep.Name := RName;
          Rep.Host := Server;
          Rep.Path := Path;
          Rep.UserName := UserName;
          Rep.ServerType := ServerType;
          UpdateRepositoriesListItem(li, Rep);
        end;
      end
      else
        Done := True;
    end;
  finally
    RepForm.Free;
  end;
end;

end.
